package com.example.utils;

import java.util.Base64;

import com.example.types.Fingerprint;
import com.example.types.PersonFingerprintData;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.machinezoo.sourceafis.FingerprintTemplate;

public class JavaResponse {

    private String id;
    private String operation;
    private String status;
    private String message;
    private PersonFingerprintData data;
    private Double score;
    private Integer edgeScore;

    // Constructor
    public JavaResponse(String id, String operation, String status, String message, PersonFingerprintData data, Double score, Integer edgeScore) {
        // logic here
        this.id = id;
        this.operation = operation;
        this.status = status;
        this.message = message;
        this.data = data;
        this.score = score;
        this.edgeScore = edgeScore;
    }

    // Getters and Setters
    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getOperation() {
        return operation;
    }

    public void setOperation(String status) {
        this.status = status;
    }

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public PersonFingerprintData getData() {
        return data;
    }

    public void setData(PersonFingerprintData data) {
        this.data = data;
    }

    public Double getScore() {
        return score;
    }

    public void setData(Double score) {
        this.score = score;
    }

    public Integer getEdgeScore() {
        return edgeScore;
    }

    public void setEdgeScore(Integer edgeScore) {
        this.edgeScore = edgeScore;
    }

    public static String buildJavaResponse(
            String id,
            String operation,
            String status,
            String message,
            FingerprintTemplate fingerprintTemplate,
            double score,
            int edgeScore,
            PersonFingerprintData personInfo,
            int fingerPosition) {

        // Convert the FingerprintTemplate to a base64-encoded string (assuming `FingerprintTemplate` has a way to do this)
        String templateBase64 = (fingerprintTemplate != null) ? Base64.getEncoder().encodeToString(fingerprintTemplate.toByteArray()) : "";

        // Construct the fingerprint data (if there is a fingerprint template)
        Fingerprint fingerprint = new Fingerprint(personInfo.getName(), fingerPosition, templateBase64);

        // Add the fingerprint to the personInfo
        personInfo.addFingerprint(fingerprint);

        // Build the JavaResponse
        JavaResponse javaResponse = new JavaResponse(id, operation, status, message, personInfo, score, edgeScore);
        // System.out.println("Java Response: " + javaResponse.toString());

        // Serialize JavaResponse to JSON string using Jackson
        try {
            ObjectMapper mapper = new ObjectMapper();
            String jsonResponse = mapper.writeValueAsString(javaResponse);
            return jsonResponse;
        } catch (Exception e) {
            // Handle exception if serialization fails
            e.printStackTrace();
            return "{\"error\":\"Failed to serialize response\"}";
        }
    }

}
