package com.example.utils;

import java.io.ByteArrayInputStream;
import java.io.IOException;

import com.fasterxml.jackson.dataformat.cbor.CBORFactory;
import com.fasterxml.jackson.dataformat.cbor.CBORParser;
import com.machinezoo.sourceafis.FingerprintTransparency;

public class TransparencyContents extends FingerprintTransparency {

    private int edgeNumber = 0;

    @Override
    public void take(String key, String mime, byte[] data) {
        try {
            if (key.equals("edge-table")) {
                CBORFactory cborFactory = new CBORFactory();
                ByteArrayInputStream inputStream = new ByteArrayInputStream(data);
                try (CBORParser cborParser = cborFactory.createParser(inputStream)) {
                    while (cborParser.nextToken() != null) {
                        if (cborParser.getText().equals("length")) {
                            edgeNumber++;
                        }
                    }
                    countEdgeNumber();
                } catch (IOException e) {
                    throw new IOException("Counting edge error");
                }
            }
        } catch (NullPointerException | IOException ex) {
            System.out.println("Error: " + ex);
        }
    }

    @Override
    public boolean accepts(String key) {
        return super.accepts(key);
    }

    public Integer countEdgeNumber() {
        return edgeNumber;
    }

    // Static helper method to use this class easily
    public static Integer calculateEdgeScore(byte[] imageBytes) {
        Integer edgeScore = null;
        try (TransparencyContents transparency = new TransparencyContents()) {
            // FingerprintTemplate probe = new FingerprintTemplate(new FingerprintImage(imageBytes));
            transparency.accepts("edge-table");
            transparency.take("edge-table", "application/cbor", imageBytes);
            edgeScore = transparency.countEdgeNumber();
        } catch (Exception e) {
            System.out.println("Error calculating edge score: " + e.getMessage());
        }
        return edgeScore;
    }
}
